@@ -4,9 +4,12 @@ from edgedb_orm import is_unset
 
 
 class BasePatch(BaseModel):
-    def updated_fields(self, exclude: T.Set[str] = None) -> T.Set[str]:
+    def updated_fields(
+        self, exclude: T.Set[str] = None, exclude_last_updated: bool = False
+    ) -> T.Set[str]:
         if exclude is None:
             exclude = set()
+        exclude.add("last_updated")
         return {
             field
             for field in self.__fields__
